summaryrefslogtreecommitdiffstats
path: root/khelpcenter/htmlsearch/ktagcombobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'khelpcenter/htmlsearch/ktagcombobox.h')
-rw-r--r--khelpcenter/htmlsearch/ktagcombobox.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/khelpcenter/htmlsearch/ktagcombobox.h b/khelpcenter/htmlsearch/ktagcombobox.h
index 28aad2dc8..a246e2140 100644
--- a/khelpcenter/htmlsearch/ktagcombobox.h
+++ b/khelpcenter/htmlsearch/ktagcombobox.h
@@ -25,13 +25,13 @@
#ifndef __KTAGCOMBOBOX_H__
#define __KTAGCOMBOBOX_H__
-#include <qcombobox.h>
+#include <tqcombobox.h>
class QPopupMenu;
/*
* This class should be just like qcombobox, but it should be possible
* to have have a QIconSet for each entry, and each entry should have a tag.
*
* It has also support for sub menues.
*/
@@ -40,13 +40,13 @@ class KTagComboBox : public QComboBox
Q_OBJECT
public:
- KTagComboBox(QWidget *parent=0, const char *name=0);
+ KTagComboBox(TQWidget *parent=0, const char *name=0);
~KTagComboBox();
- void insertItem(const QIconSet& icon, const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1 );
- void insertItem(const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1 );
- void insertSeparator(const QString &submenu = QString::null, int index=-1 );
- void insertSubmenu(const QString &text, const QString &tag, const QString &submenu = QString::null, int index=-1);
+ void insertItem(const TQIconSet& icon, const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1 );
+ void insertItem(const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1 );
+ void insertSeparator(const TQString &submenu = TQString::null, int index=-1 );
+ void insertSubmenu(const TQString &text, const TQString &tag, const TQString &submenu = TQString::null, int index=-1);
int count() const;
void clear();
@@ -54,19 +54,19 @@ public:
/*
* Tag of the selected item
*/
- QString currentTag() const;
- QString tag ( int i ) const;
- bool containsTag (const QString &str ) const;
+ TQString currentTag() const;
+ TQString tag ( int i ) const;
+ bool containsTag (const TQString &str ) const;
/*
* Set the current item
*/
int currentItem() const;
void setCurrentItem(int i);
- void setCurrentItem(const QString &code);
+ void setCurrentItem(const TQString &code);
// widget stuff
- virtual void setFont( const QFont & );
+ virtual void setFont( const TQFont & );
signals:
void activated( int index );
@@ -77,15 +77,15 @@ private slots:
void internalHighlight( int );
protected:
- void paintEvent( QPaintEvent * );
- void mousePressEvent( QMouseEvent * );
- void keyPressEvent( QKeyEvent *e );
+ void paintEvent( TQPaintEvent * );
+ void mousePressEvent( TQMouseEvent * );
+ void keyPressEvent( TQKeyEvent *e );
void popupMenu();
private:
// work space for the new class
- QStringList *tags;
- QPopupMenu *popup, *old_popup;
+ TQStringList *tags;
+ TQPopupMenu *popup, *old_popup;
int current;
};
@@ -25,13 +25,13 @@
/*
* This class should be just like qcombobox, but it should be possible
- * to have have a QIconSet for each entry, and each entry should have a tag.
+ * to have have a TQIconSet for each entry, and each entry should have a tag.
*
* It has also support for sub menues.